[eGroupWare-svn] r56067 - in /trunk/egroupware/api: inc/ src/ src/Db/ src/Egw/ src/Link/ src/Storage/ src/Vfs/

[email protected] Fri, 06 May 2016 11:13:20 -0000
Newsgroups gmane.comp.web.egroupware.cvs
Message-ID <[email protected]>
Author: ralfbecker
Date: Fri May  6 13:13:19 2016
New Revision: 56067

URL: http://svn.stylite.de/viewvc/egroupware?rev=56067&view=rev
Log:
fix diverse occurences of egw_db

Modified:
    trunk/egroupware/api/inc/class.egw_exception_db.inc.php
    trunk/egroupware/api/src/Config.php
    trunk/egroupware/api/src/Contacts.php
    trunk/egroupware/api/src/Db/Backup.php
    trunk/egroupware/api/src/Db/Exception.php
    trunk/egroupware/api/src/Db/Schema.php
    trunk/egroupware/api/src/Egw/Applications.php
    trunk/egroupware/api/src/Link/Storage.php
    trunk/egroupware/api/src/Preferences.php
    trunk/egroupware/api/src/Session.php
    trunk/egroupware/api/src/Storage/Customfields.php
    trunk/egroupware/api/src/Vfs/Sharing.php

Modified: trunk/egroupware/api/inc/class.egw_exception_db.inc.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/inc/class.egw_exception_db.inc.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/inc/class.egw_exception_db.inc.php (original)
+++ trunk/egroupware/api/inc/class.egw_exception_db.inc.php Fri May  6 13:13:19 2016
@@ -14,7 +14,7 @@
 use EGroupware\Api;
 
 /**
- * Exception thrown by the egw_db class for everything not covered by extended classed below
+ * Exception thrown by the Api\Db class for everything not covered by extended classed below
  *
  * New Db\Exception has to extend deprecated egw_exception_db to allow legacy code
  * to catch exceptions thrown by Api\Db class!

Modified: trunk/egroupware/api/src/Config.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Config.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Config.php (original)
+++ trunk/egroupware/api/src/Config.php Fri May  6 13:13:19 2016
@@ -332,8 +332,8 @@
 	 */
 	public static function init_static()
 	{
-		// we use a reference here (no clone), as we no longer use egw_db::row() or egw_db::next_record()!
-		if (isset($GLOBALS['egw_setup']) && is_a($GLOBALS['egw_setup']->db, 'egw_db'))
+		// we use a reference here (no clone), as we no longer use Db::row() or Db::next_record()!
+		if (isset($GLOBALS['egw_setup']) && $GLOBALS['egw_setup']->db instanceof Db)
 		{
 			self::$db = $GLOBALS['egw_setup']->db;
 		}

Modified: trunk/egroupware/api/src/Contacts.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Contacts.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Contacts.php (original)
+++ trunk/egroupware/api/src/Contacts.php Fri May  6 13:13:19 2016
@@ -163,9 +163,9 @@
 	 * Constructor
 	 *
 	 * @param string $contact_app ='addressbook' used for acl->get_grants()
-	 * @param egw_db $db =null
-	 */
-	function __construct($contact_app='addressbook',egw_db $db=null)
+	 * @param Db $db =null
+	 */
+	function __construct($contact_app='addressbook',Db $db=null)
 	{
 		parent::__construct($contact_app,$db);
 		if ($this->log)
@@ -1549,7 +1549,7 @@
 			$options['filter'] = (array)$options['filter'];
 		}
 		// return only contacts with email set
-		$options['filter'][] = "contact_email ".$this->db->capabilities[egw_db::CAPABILITY_CASE_INSENSITIV_LIKE]." '%@%'";
+		$options['filter'][] = "contact_email ".$this->db->capabilities[Db::CAPABILITY_CASE_INSENSITIV_LIKE]." '%@%'";
 
 		// let link query know, to append email to list
 		$options['type'] = 'email';

Modified: trunk/egroupware/api/src/Db/Backup.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Db/Backup.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Db/Backup.php (original)
+++ trunk/egroupware/api/src/Db/Backup.php Fri May  6 13:13:19 2016
@@ -87,7 +87,7 @@
 	 */
 	var $backup_files = false ;
 	/**
-	 * Reference to schema_proc's egw_db object
+	 * Reference to schema_proc's Api\Db object
 	 *
 	 * @var Api\Db
 	 */

Modified: trunk/egroupware/api/src/Db/Exception.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Db/Exception.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Db/Exception.php (original)
+++ trunk/egroupware/api/src/Db/Exception.php Fri May  6 13:13:19 2016
@@ -14,7 +14,7 @@
 namespace EGroupware\Api\Db;
 
 /**
- * Exception thrown by the egw_db class for everything not covered by extended classed below
+ * Exception thrown by the Api\Db class for everything not covered by extended classed below
  *
  * New Db\Exception has to extend deprecated egw_exception_db to allow legacy code
  * to catch exceptions thrown by Api\Db class!

Modified: trunk/egroupware/api/src/Db/Schema.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Db/Schema.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Db/Schema.php (original)
+++ trunk/egroupware/api/src/Db/Schema.php Fri May  6 13:13:19 2016
@@ -916,7 +916,7 @@
 	 */
 	function ExecuteSqlArray($aSql,$debug_level)
 	{
-		if ($this->m_odb->query_log)	// we use egw_db::query to log the queries
+		if ($this->m_odb->query_log)	// we use Db::query to log the queries
 		{
 			$retval = 2;
 			foreach($aSql as $sql)

Modified: trunk/egroupware/api/src/Egw/Applications.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Egw/Applications.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Egw/Applications.php (original)
+++ trunk/egroupware/api/src/Egw/Applications.php Fri May  6 13:13:19 2016
@@ -23,7 +23,7 @@
 	/**
 	 * Reference to the global db class
 	 *
-	 * @var egw_db
+	 * @var EGroupware\Api\Db
 	 */
 	var $db;
 	var $table_name = 'egw_applications';

Modified: trunk/egroupware/api/src/Link/Storage.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Link/Storage.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Link/Storage.php (original)
+++ trunk/egroupware/api/src/Link/Storage.php Fri May  6 13:13:19 2016
@@ -39,7 +39,7 @@
 	/**
 	 * Reference to the global db-class
 	 *
-	 * @var egw_db
+	 * @var Api\Db
 	 */
 	private static $db;
 	/**

Modified: trunk/egroupware/api/src/Preferences.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Preferences.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Preferences.php (original)
+++ trunk/egroupware/api/src/Preferences.php Fri May  6 13:13:19 2016
@@ -86,7 +86,7 @@
 	 */
 	var $session = array();
 	/**
-	 * @var egw_db
+	 * @var Db
 	 */
 	var $db;
 	/**

Modified: trunk/egroupware/api/src/Session.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Session.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Session.php (original)
+++ trunk/egroupware/api/src/Session.php Fri May  6 13:13:19 2016
@@ -54,7 +54,7 @@
 	/**
 	 * key of eGW's required files in $_SESSION
 	 *
-	 * These files get set by egw_db and egw class, for classes which get not autoloaded (eg. ADOdb, idots_framework)
+	 * These files get set by Db and Egw class, for classes which get not autoloaded (eg. ADOdb, idots_framework)
 	 */
 	const EGW_REQUIRED_FILES = 'egw_required_files';
 

Modified: trunk/egroupware/api/src/Storage/Customfields.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Storage/Customfields.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================
--- trunk/egroupware/api/src/Vfs/Sharing.php (original)
+++ trunk/egroupware/api/src/Vfs/Sharing.php Fri May  6 13:13:19 2016
@@ -52,7 +52,7 @@
 	/**
 	 * Reference to global db object
 	 *
-	 * @var egw_db
+	 * @var Api\Db
 	 */
 	protected static $db;
 


------------------------------------------------------------------------------
Find and fix application performance issues faster with Applications Manager
Applications Manager provides deep performance insights into multiple tiers of
your business applications. It resolves application problems quickly and
reduces your MTTR. Get your free trial!
https://ad.doubleclick.net/ddm/clk/302982198;130105516;z
--- trunk/egroupware/api/src/Storage/Customfields.php (original)
+++ trunk/egroupware/api/src/Storage/Customfields.php Fri May  6 13:13:19 2016
@@ -59,10 +59,10 @@
 	 * @param string $only_type2 =null if given only return fields of type2 == $only_type2
 	 * @param int $start =0
 	 * @param int $num_rows =null
 	 * @param egw_db $db =null reference to database instance to use
 	 * @return array with customfields
 	 */
-	function __construct($app, $all_private_too=false, $only_type2=null, $start=0, $num_rows=null, egw_db $db=null)
+	function __construct($app, $all_private_too=false, $only_type2=null, $start=0, $num_rows=null, Api\Db $db=null)
 	{
 		$this->app = $app;
 		$this->all_private_too = $all_private_too;
@@ -88,7 +88,7 @@
 	/**
 	 * Return iterator required for IteratorAggregate
 	 *
-	 * @return egw_db_callback_iterator
+	 * @return Api\Db\CallbackIterator
 	 */
 	function getIterator()
 	{
@@ -129,10 +129,10 @@
 	 * @param string $app
 	 * @param boolean $all_private_too =false should all the private fields be returned too, default no
 	 * @param string $only_type2 =null if given only return fields of type2 == $only_type2
 	 * @param egw_db $db =null reference to database to use
 	 * @return array with customfields
 	 */
-	public static function get($app, $all_private_too=false, $only_type2=null, egw_db $db=null)
+	public static function get($app, $all_private_too=false, $only_type2=null, Api\Db $db=null)
 	{
 		$cache_key = $app.':'.($all_private_too?'all':$GLOBALS['egw_info']['user']['account_id']).':'.$only_type2;
 		$cfs = Api\Cache::getInstance(__CLASS__, $cache_key);
@@ -59,10 +59,10 @@
 	 * @param int $start =0
 	 * @param int $num_rows =null
-	 * @param egw_db $db =null reference to database instance to use
+	 * @param Api\Db $db =null reference to database instance to use
 	 * @return array with customfields
 	 */
@@ -129,10 +129,10 @@
 	 * @param boolean $all_private_too =false should all the private fields be returned too, default no
 	 * @param string $only_type2 =null if given only return fields of type2 == $only_type2
-	 * @param egw_db $db =null reference to database to use
+	 * @param Api\Db $db =null reference to database to use
 	 * @return array with customfields
 	 */

Modified: trunk/egroupware/api/src/Vfs/Sharing.php
URL: http://svn.stylite.de/viewvc/egroupware/trunk/egroupware/api/src/Vfs/Sharing.php?rev=56067&r1=56066&r2=56067&view=diff
==============================================================================